projectal.entities.project_template API documentation

# projectal.entities.project_template

View Source

    from projectal import api
    from projectal.entity import Entity

    class ProjectTemplate(Entity):
        """
        Implementation of the
        [Project Template](https://projectal.com/docs/latest/#tag/Project-Template) API.
        """
        _path = 'template/project'
        _name = 'PROJECT_TEMPLATE'

        @classmethod
        def autoschedule(cls, project, mode='ASAP'):
            """
            Autoschedule the project template.

            `project`: A ProjectTemplate entity

            `mode`: `ASAP` or `ALAP`
            """
            url = '/api/template/project/schedule?mode={}'.format(mode)
            api.post(url, [project])
            return True

class ProjectTemplate(projectal.entity.Entity):
View Source

    class ProjectTemplate(Entity):
        """
        Implementation of the
        [Project Template](https://projectal.com/docs/latest/#tag/Project-Template) API.
        """
        _path = 'template/project'
        _name = 'PROJECT_TEMPLATE'

        @classmethod
        def autoschedule(cls, project, mode='ASAP'):
            """
            Autoschedule the project template.

            `project`: A ProjectTemplate entity

            `mode`: `ASAP` or `ALAP`
            """
            url = '/api/template/project/schedule?mode={}'.format(mode)
            api.post(url, [project])
            return True

Implementation of the Project Template API.

@classmethod
def autoschedule(cls, project, mode='ASAP'):
View Source

        @classmethod
        def autoschedule(cls, project, mode='ASAP'):
            """
            Autoschedule the project template.

            `project`: A ProjectTemplate entity

            `mode`: `ASAP` or `ALAP`
            """
            url = '/api/template/project/schedule?mode={}'.format(mode)
            api.post(url, [project])
            return True

Autoschedule the project template.

`project`: A ProjectTemplate entity

`mode`: `ASAP` or `ALAP`

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  create
  save
  clone
  history
  list
  match
  match_startswith
  match_endswith
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy